aboutsummaryrefslogtreecommitdiffstats
path: root/repository/repo.go
diff options
context:
space:
mode:
Diffstat (limited to 'repository/repo.go')
-rw-r--r--repository/repo.go14
1 files changed, 8 insertions, 6 deletions
diff --git a/repository/repo.go b/repository/repo.go
index 7d655bde..71bd7a8e 100644
--- a/repository/repo.go
+++ b/repository/repo.go
@@ -10,8 +10,10 @@ import (
"github.com/MichaelMure/git-bug/util/lamport"
)
-var ErrNoConfigEntry = errors.New("no config entry for the given key")
-var ErrMultipleConfigEntry = errors.New("multiple config entry for the given key")
+var (
+ ErrNoConfigEntry = errors.New("no config entry for the given key")
+ ErrMultipleConfigEntry = errors.New("multiple config entry for the given key")
+)
// RepoCommon represent the common function the we want all the repo to implement
type RepoCommon interface {
@@ -109,13 +111,13 @@ type ClockedRepo interface {
// EditTimeIncrement increment the edit clock and return the new value.
EditTimeIncrement() (lamport.Time, error)
// CreateWitness witness another create time and increment the corresponding
// clock if needed.
- CreateWitness(time lamport.Time) error
+ WitnessCreate(time lamport.Time) error
- // EditWitness witness another edition time and increment the corresponding
+ // WitnessEdit witness another edition time and increment the corresponding
// clock if needed.
- EditWitness(time lamport.Time) error
+ WitnessEdit(time lamport.Time) error
}
// Witnesser is a function that will initialize the clocks of a repo
@@ -109,13 +111,13 @@ type ClockedRepo interface {
// EditTimeIncrement increment the edit clock and return the new value.
EditTimeIncrement() (lamport.Time, error)
- // CreateWitness witness another create time and increment the corresponding
+ // WitnessCreate witness another create time and increment the corresponding
// clock if needed.